@@ -14,7 +14,7 @@ loaded.
 @author: Peter Parente
 @author: Brett Clippingdale
 @organization: IBM Corporation
-@copyright: Copyright (c) 2005, 2006 IBM Corporation
+@copyright: Copyright (c) 2005, 2007 IBM Corporation
 @license: The BSD License
 
 All rights reserved. This program and the accompanying materials are made
@@ -22,30 +22,8 @@ available under the terms of the BSD license which accompanies
 this distribution, and is available at
 U{http://www.opensource.org/licenses/bsd-license.php}
 '''
-from Base import AEOutput
+from Base import *
 from Audio import Audio
 from Braille import Braille
 from Style import *
 from Error import *
-from Constants import *
-import Constants
-
-def getDefaults():
-  '''
-  Suggests the default L{AEOutput}s events to be monitored.
-  
-  @return: Names of defaults to monitor
-  @rtype: list of string
-  '''
-  return Constants.default_types
-  
-def getNames():
-  '''
-  Gets the names of all the L{AEOutput} command types.
-  
-  @return: List of all known L{AEOutput} command names
-  @rtype: list of string
-  '''
-  names = Constants.all_types
-  names.sort()
-  return names
\ No newline at end of file
