@@ -1,5 +1,5 @@
 '''
-Defines default L{AccAdapt.Adapter}s for the L{LSRInterfaces.IEventHandler} 
+Defines default L{AccAdapt.Adapter}s for the L{AEInterfaces.IEventHandler} 
 interface on L{pyLinAcc.Accessible} objects.
 
 @var EVENT_HANDLERS: Maps event names to method names to be called to 
@@ -24,7 +24,7 @@ U{http://www.opensource.org/licenses/bsd-license.php}
 from POR import POR
 from AEEvent import *
 from AccAdapt import Adapter
-from LSRInterfaces import *
+from AEInterfaces import *
 from pyLinAcc import Interfaces, Constants
 import pyLinAcc, AEConstants
 
@@ -45,6 +45,7 @@ AE_MAP = {ViewChange : ['window:activate', 'window:deactivate',
           StateChange : ['object:state-changed:expanded', 
                          'object:state-changed:checked',
                          'object:state-changed:enabled',
+                         'object:state-changed:sensitive',
                          'object:state-changed:animated',
                          'object:state-changed:busy',
                          'object:state-changed:visible',
