@@ -1,5 +1,5 @@
 '''
-Defines default L{AccAdapt.Adapter}s for the L{LSRInterfaces.IAccessibleInfo} 
+Defines default L{AccAdapt.Adapter}s for the L{AEInterfaces.IAccessibleInfo} 
 interface on L{pyLinAcc.Accessibility.Accessible} objects.
 
 @author: Peter Parente
@@ -18,7 +18,7 @@ U{http://www.opensource.org/licenses/bsd-license.php}
 import pyLinAcc
 from POR import POR
 from AccAdapt import PORAdapter
-from LSRInterfaces import *
+from AEInterfaces import *
 from pyLinAcc import Constants, Interfaces
 
 class DefaultAccInfoAdapter(PORAdapter):
@@ -68,11 +68,15 @@ class DefaultAccInfoAdapter(PORAdapter):
     @raise LookupError: When the accessible object is dead
     @raise NotImplementedError: When this accessible does not support object
       attributes
-    '''
+    ''' 
     try:
       attrs = self.accessible.getAttributes()
     except (AttributeError, Constants.NotImplemented,Constants.CORBAException):
-      raise NotImplementedError
+      try:
+        doc = Interfaces.IDocument(self.accessible)
+        attrs = doc.getAttributes()
+      except (AttributeError, Constants.NotImplemented,Constants.CORBAException):
+        raise NotImplementedError
     return dict([attr.split(':', 1) for attr in attrs])
 
   @pyLinAcc.errorToLookupError
@@ -843,7 +847,14 @@ class DefaultAccInfoAdapter(PORAdapter):
     @rtype: string
     @raise LookupError: When the accessible object is invalid
     '''
-    return Interfaces.IHyperlink(self.subject).getURI(index)
+    # temporary workaround for mozilla bug #379747
+    if self.subject.accessible.getApplication().toolkitName == 'Gecko':
+      ht = Interfaces.IHypertext(self.subject.accessible.parent)
+      c = IAccessibleInfo(self.subject).getAccIndex()
+      h = ht.getLink(c)
+      return h.getURI(index)
+    else:
+      return Interfaces.IHyperlink(self.subject).getURI(index)
   
   def getAccAnchorCount(self):
     ''' 
