@@ -24,7 +24,7 @@ import pyLinAcc
 from DefaultNav import *
 from DefaultInfo import *
 from TextAdapter import *
-from LSRInterfaces import *
+from AEInterfaces import *
 from pyLinAcc import Interfaces, Constants
 
 EMBED_CHAR = u'\ufffc'
