@@ -143,6 +143,8 @@ class CliqueAudio(AEOutput.Audio):
     dd = math.pi / num_layers
     # create one channel so we can talk to the engine
     sch, nch = self._createNewChannel(0)
+    voice_offset = 0
+    pitch_offset = 0
     for l in xrange(0, num_layers):
       # position in a semicircle in front of the user
       a = l * (-1)**l
@@ -154,16 +156,18 @@ class CliqueAudio(AEOutput.Audio):
         s = CliqueAudioStyle(self.default_style)
         s.init(self)
         # get a unique voice within this set
-        v_num = (i % 8) + 1
+        v_num = (i+voice_offset % 8) + 1
         v = sch.tts.getVoice(v_num)
         s.Voice = v_num
         # set values relative to the default
-        s.Pitch = v.pitchBaseline
+        s.Pitch = v.pitchBaseline + pitch_offset
         # set to the position and channel of this layer
         s.PosX = 0.5*x
         s.PosY = 0.5*y
         s.Channel = l
         styles.append(s)
+      voice_offset += 1
+      pitch_offset += 20
     return styles
 
   def close(self):
@@ -499,25 +503,6 @@ class SpeechChannel(Channel):
     self.mode = pySonicEx.OPENRAW|pySonicEx.OPENMEMORY|pySonicEx.ThreeD
     self.start()
     
-  def _localize(self, text, style):
-    '''
-    Converts the given unicode text to CP1252 or UTF-16 depending on the 
-    language flag in the style.
-
-    @note: Larry says IBM TTS expects all Asian language strings to be encoded
-      in UCS-2, predecessor of UTF-16, and all others in CP1252.
-    @param text: Text to localize
-    @type text: unicode
-    @param style: Style object indicating the language and locale
-    @type style: L{AEOutput.Style}
-    @return: Localized string
-    @rtype: string
-    '''
-    if self.tts.languageDialect in UTF16_LANGS:
-      return text.encode('utf-16', 'ignore')
-    else:
-      return text.encode('cp1252', 'ignore')
-        
   def put(self, text, style):
     '''
     Buffers text and style information for later synthesis. If the style 
@@ -574,7 +559,7 @@ class SpeechChannel(Channel):
           self.last_style = msg.style
         # queue new text
         if msg.text is not None:
-          self.tts.addText(self._localize(msg.text, msg.style))
+          self.tts.addText(msg.text)
       elif (msg.cmd == msg.TALK or talk == True) and self.tts.speaking():
         # synthesize speech synchrnously to the buffer
         self.tts.synthSync()
