@@ -29,7 +29,7 @@ from i18n import _
 DEBUG = False
 
 def_keymap = gdk.keymap_get_default()
-MAX_KEY_CHORD = 3
+MAX_KEY_CHORD = 4
 
 __uie__ = dict(kind='device')
 
@@ -600,7 +600,7 @@ class Keyboard(AEInput.SystemInput):
         # take the released key out of the gesture
         self.curr_gesture.removeActionCode(code)
       except ValueError:
-        print 'error removing:', code
+        pass
       self._debug('ignored our release', code, event, False)
       return
     elif len(self.synth_press):
