@@ -29,7 +29,7 @@ class CyclicInputTask(InputTask.InputTask):
   '''
   Base.registerTaskType('CyclicInputTask', False)
   
-  def __init__(self, ident=None, *names):
+  def __init__(self, ident, *names):
     '''
     Stores a sequence of named L{InputTask}s to execute.
     
@@ -38,7 +38,7 @@ class CyclicInputTask(InputTask.InputTask):
     @param names: Names of L{Task}s that should be executed
     @type names: list of string
     '''
-    InputTask.InputTask.__init__(self, ident=ident)
+    InputTask.InputTask.__init__(self, ident)
     self.names = names
     
   def execute(self, cycle_count, layer, **kwargs):
@@ -57,6 +57,9 @@ class CyclicInputTask(InputTask.InputTask):
       invoked L{Task}.
     @rtype: boolean
     '''
+    if not len(self.names):
+      # do nothing if no tasks to cycle
+      return
     i = cycle_count % len(self.names)
     return self.doTask(self.names[i], **kwargs)
   
@@ -76,5 +79,8 @@ class CyclicInputTask(InputTask.InputTask):
       invoked L{Task}.
     @rtype: boolean
     '''
+    if not len(self.names):
+      # do nothing if no tasks to cycle
+      return
     i = cycle_count % len(self.names)
     return self.doTask(self.names[i], propagate=False, **kwargs)
