@@ -3,7 +3,7 @@ Defines a L{Task} to execute when the state of an accesible or item changes.
 
 @author: Peter Parente
 @organization: IBM Corporation
-@copyright: Copyright (c) 2006 IBM Corporation
+@copyright: Copyright (c) 2005, 2007 IBM Corporation
 @license: The BSD License
 
 All rights reserved. This program and the accompanying materials are made 
@@ -12,19 +12,19 @@ this distribution, and is available at
 U{http://www.opensource.org/licenses/bsd-license.php}
 '''
 
-import EventTask, Constants
+import Base, EventTask
 import AEEvent
 
 class StateTask(EventTask.EventTask):
   '''
   Executed when the state of an accesible or item changes.
 
-  This class registers its name and whether it should be monitored by default in
-  an L{AEMonitor} using the L{Constants.registerTaskType} function
-  when this module is first imported. The L{AEMonitor} can use this
-  information to build its menus.
+  This class registers its name and whether it should be monitored by default
+  in an L{AEMonitor} using the L{Base.registerTaskType} function when this
+  module is first imported. The L{AEMonitor} can use this information to build
+  its menus. 
   '''
-  Constants.registerTaskType('StateTask', False)
+  Base.registerTaskType('StateTask', False)
 
   def getEventType(self):
     '''
@@ -44,8 +44,7 @@ class StateTask(EventTask.EventTask):
     @type name: string
     @param value: True if the state is now set, False if not
     @type value: boolean
-    @param layer: Layer on which the event occurred, one of L{Task.LAYER_FOCUS},
-      L{Task.LAYER_TIER}, or L{Task.LAYER_BACKGROUND}
+    @param layer: Layer on which the event occurred
     @type layer: integer
     '''
     pass
@@ -61,8 +60,7 @@ class StateTask(EventTask.EventTask):
     @type name: string
     @param value: True if the state is now set, False if not
     @type value: boolean
-    @param layer: Layer on which the event occurred, one of L{Task.LAYER_FOCUS},
-      L{Task.LAYER_TIER}, or L{Task.LAYER_BACKGROUND}
+    @param layer: Layer on which the event occurred
     @type layer: integer
     @return: True to allow other L{Task}s to process this event
     @rtype: boolean
