@@ -16,7 +16,7 @@ import logging
 import AEEvent, AEState, AEMonitor, AEConstants, UIRegistrar
 from Tier import Tier
 from UIRegistrar import MONITOR, PERK
-from LSRInterfaces import implements
+from AEInterfaces import implements
 from i18n import _
 
 log = logging.getLogger('Tier')
@@ -199,7 +199,7 @@ class TierManager(object):
     Informs L{AEMonitor}s added via L{addMonitors} of the propagation return
     value from a L{Task}.
     
-    @param propagate: Was the event consumed (False) or allowed to propogate 
+    @param propagate: Was the event consumed (False) or allowed to propagate 
       (True)?
     @type propagate: boolean
     '''
@@ -349,6 +349,7 @@ class TierManager(object):
       # focus, then the layer is always the tier layer
       event.setLayer(AEConstants.LAYER_TIER)
     # let the tier manage the event
+    tier.setShow(len(self.monitors))
     tier.manageEvent(event)
     tier.clearState()
    
@@ -361,7 +362,8 @@ class TierManager(object):
     @param event: Event to dispatch to the L{Tier}
     @type event: L{AEEvent.Base.AccessEngineEvent}
     '''
-    if self.active_tier is not None:
+    tier = self.active_tier
+    if tier is not None:
       # keep track of sequences of input gestures
       g = event.getTaskKey()
       if g == self.gesture[0]:
@@ -370,8 +372,9 @@ class TierManager(object):
         self.gesture[0] = g
         self.gesture[1] = 0
       # let the active Tier manage the event
-      self.active_tier.manageGesture(event, self.gesture[1])
-      self.active_tier.clearState()
+      tier.setShow(len(self.monitors))
+      tier.manageGesture(event, self.gesture[1])
+      tier.clearState()
       
   def manageChooser(self, event):
     '''
@@ -390,6 +393,7 @@ class TierManager(object):
     except KeyError:
       return
     # let that Tier manage the event
+    tier.setShow(len(self.monitors))
     tier.manageKeyedTask(event)
     tier.clearState()
     
@@ -412,6 +416,7 @@ class TierManager(object):
       # the event came from an unfocused control in the active tier
       event.setLayer(AEConstants.LAYER_TIER)
     # let that Tier manage the event
+    tier.setShow(len(self.monitors))
     tier.manageKeyedTask(event) 
     tier.clearState()
 
