@@ -10,7 +10,7 @@ Functions to install, uninstall, associate, disassociate, and list UIEs are
 primarily of interest to third-party UIE developers and expert users. These
 methods allow extensions to be added to LSR and associated with profiles so
 they are loaded automatically at startup or when L{Tier}s are created. The
-L{LSRMain} script defines a command line interface for accessing these
+L{AEMain} script defines a command line interface for accessing these
 methods. See the documentation in that module or the LSR man page for details.
   
 Functions to load UIEs are of interest to LSR developers. Given a UIE name, the
